package com.gmei.data.monitor.utils;

import java.sql.*;
import java.util.List;

/**
 * ClassName: MysqlJdbcBl
 * Function:
 * Reason: 单例模式的数据下发jdbc工具
 * Date: 2019/12/7 上午11:01
 *
 * @author liuzhe
 * @since JDK 1.8
 */
public class MysqlUtil {
    private volatile static MysqlUtil mysqlJdbcBl = null;

    private String driver = "com.mysql.jdbc.Driver";
    private String url;
    private Connection conn;

    private MysqlUtil(String url) {
        this.url = url;
    }

    public static MysqlUtil getInstance(String url) {
        if (mysqlJdbcBl == null) {
            synchronized (MysqlUtil.class) {
                if(mysqlJdbcBl == null) {
                    mysqlJdbcBl = new MysqlUtil(url);
                }
            }
        }
        return mysqlJdbcBl;
    }

    public Connection getConnection() {
        try {
            Class.forName(driver);
            if(conn == null || conn.isClosed()) {
                conn = DriverManager.getConnection(url);
            }
        } catch (ClassNotFoundException e) {
            e.printStackTrace();
        } catch (SQLException e) {
            e.printStackTrace();
        }
        return conn;
    }

    public void update(String sql, List<Object> params) throws SQLException {
        PreparedStatement ps = null;
        try {
            ps = conn.prepareStatement(sql);
            if (params != null && params.size() > 0) {
                for (int i = 0; i < params.size(); i++) {
                    ps.setObject(i + 1, params.get(i));
                }
            }
            ps.executeUpdate();
        } catch (SQLException e) {
            e.printStackTrace();
        } finally {
            ps.close();
        }
    }

    public void insert(String sql) throws SQLException {
        Statement st = null;
        try {
            st = conn.createStatement();
            st.executeUpdate(sql);
        } catch (SQLException e) {
            e.printStackTrace();
        } finally {
            st.close();
        }
    }

    public ResultSet find(String sql) {
        if(conn == null){
            conn = getConnection();
        }
        ResultSet rs = null;
        Statement st = null;
        try {
            st = conn.createStatement();
            rs = st.executeQuery(sql);
        } catch (SQLException e) {
            e.printStackTrace();
        }
        return rs;
    }

    public void close(Connection con, Statement st, ResultSet rs) {
        if (rs != null) {
            try {
                rs.close();
            } catch (SQLException e) {
                e.printStackTrace();
            }
            if (st != null) {
                try {
                    st.close();
                } catch (SQLException e) {
                    e.printStackTrace();
                }
            }
            if (con != null) {
                try {
                    con.close();
                } catch (SQLException e) {
                    e.printStackTrace();
                }
            }
        }
    }
}
